tsseg.algorithms.clap package
=============================

Two related algorithms sharing core routines:

* **ClaSP** (Classification Score Profile): parameter-free CPD using binary
  classifier scoring. *Type: change point detection.*
* **CLaP** (Classification Label Profile): extension for state detection using
  ``aeon`` classifiers. *Type: state detection.*

| **Supervision:** unsupervised or semi-supervised
| **Scope:** univariate and multivariate

**Implementation:** Adapted from original ClaSP code by Arik Ermshaus. BSD 3-Clause.

**Reference:** Ermshaus, Schäfer & Leser (2023), DMKD.

Submodules
----------

tsseg.algorithms.clap.clap module
---------------------------------

.. automodule:: tsseg.algorithms.clap.clap
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.clap.clap\_detector module
-------------------------------------------

.. automodule:: tsseg.algorithms.clap.clap_detector
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.clap.clasp\_detector module
--------------------------------------------

.. automodule:: tsseg.algorithms.clap.clasp_detector
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.clap.clasp\_knn module
---------------------------------------

.. automodule:: tsseg.algorithms.clap.clasp_knn
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.clap.distance module
-------------------------------------

.. automodule:: tsseg.algorithms.clap.distance
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.clap.nearest\_neighbour module
-----------------------------------------------

.. automodule:: tsseg.algorithms.clap.nearest_neighbour
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.clap.scoring module
------------------------------------

.. automodule:: tsseg.algorithms.clap.scoring
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.clap.segmentation module
-----------------------------------------

.. automodule:: tsseg.algorithms.clap.segmentation
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.clap.utils module
----------------------------------

.. automodule:: tsseg.algorithms.clap.utils
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.clap.validation module
---------------------------------------

.. automodule:: tsseg.algorithms.clap.validation
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.clap.window\_size module
-----------------------------------------

.. automodule:: tsseg.algorithms.clap.window_size
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.clap
   :members:
   :show-inheritance:
   :undoc-members:
